# Pixel Font Build Tools

[![Python](https://img.shields.io/badge/python-3.11-brightgreen)](https://www.python.org)
[![PyPI](https://img.shields.io/pypi/v/pixel-font-build-tools)](https://pypi.org/project/pixel-font-build-tools/)

A set of tools for building pixel fonts.

## Installation

```shell
pip install pixel-font-build-tools
```

## Dependencies

- [Pixel Font Builder](https://github.com/TakWolf/pixel-font-builder)
- [Unidata Blocks](https://github.com/TakWolf/unidata-blocks)
- [PyPNG](https://gitlab.com/drj11/pypng)

## License

Under the [MIT license](LICENSE).
